Struct ZwlrScreencopyFrameV1
pub struct ZwlrScreencopyFrameV1 { /* private fields */ }wayland and Linux only.Expand description
a frame ready for copy
This object represents a single frame.
When created, a series of buffer events will be sent, each representing a supported buffer type. The “buffer_done” event is sent afterwards to indicate that all supported buffer types have been enumerated. The client will then be able to send a “copy” request. If the capture is successful, the compositor will send a “flags” event followed by a “ready” event.
For objects version 2 or lower, wl_shm buffers are always supported, ie. the “buffer” event is guaranteed to be sent.
If the capture failed, the “failed” event is sent. This can happen anytime before the “ready” event.
Once either a “ready” or a “failed” event is received, the client should destroy the frame.
See also the Event enum for this interface.
Implementations
impl ZwlrScreencopyFrameV1
impl ZwlrScreencopyFrameV1
pub fn copy(&self, buffer: &WlBuffer)
pub fn copy(&self, buffer: &WlBuffer)
copy the frame
Copy the frame to the supplied buffer. The buffer must have the correct size, see zwlr_screencopy_frame_v1.buffer and zwlr_screencopy_frame_v1.linux_dmabuf. The buffer needs to have a supported format.
If the frame is successfully copied, “flags” and “ready” events are sent. Otherwise, a “failed” event is sent.
pub fn destroy(&self)
pub fn destroy(&self)
delete this object, used or not
Destroys the frame. This request can be sent at any time by the client.
pub fn copy_with_damage(&self, buffer: &WlBuffer)
pub fn copy_with_damage(&self, buffer: &WlBuffer)
copy the frame when it’s damaged
Same as copy, except it waits until there is damage to copy.